#
# spec file for package glmark2
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2015-2016 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           glmark2
Version:        20240215
Release:        1.2
Summary:        OpenGL 2.0 and ES 2.0 benchmark
License:        GPL-3.0-only
Group:          System/X11/Utilities
URL:            https://github.com/glmark2/glmark2
Source0:        %{name}-%{version}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  gcc-c++ >= 5.0
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(x11)

%description
A benchmark for OpenGL (ES) 2.0 that uses only the OpenGL ES 2.0 compatible
API. It contains tests for standard OpenGL (ES) 2.0 features, such as vertex
arrays, VBOs, texturing and shaders.

%prep
%autosetup

%build
export CXXFLAGS="%{optflags}"
python3 waf configure \
  --with-flavors=x11-gl,x11-glesv2,wayland-gl,wayland-glesv2,drm-gl,drm-glesv2 \
  --prefix=%{_prefix}
python3 waf --verbose %{?_smp_mflags}

%install
python3 waf install --destdir=%{buildroot}
#FIXME Clean up runtime warning - libpng warning: iCCP: known incorrect sRGB profile
pushd %{buildroot}%{_datadir}/%{name}/textures
convert effect-2d.png -strip effect-2d.png
popd
%fdupes -s %{buildroot}

%files
%license COPYING COPYING.SGI
%doc NEWS
%{_bindir}/glmark2
%{_bindir}/glmark2-drm
%{_bindir}/glmark2-es2
%{_bindir}/glmark2-es2-drm
%{_bindir}/glmark2-es2-wayland
%{_bindir}/glmark2-wayland
%{_datadir}/%{name}
%{_mandir}/man1/glmark2.1%{?ext_man}
%{_mandir}/man1/glmark2-drm.1%{?ext_man}
%{_mandir}/man1/glmark2-es2.1%{?ext_man}
%{_mandir}/man1/glmark2-es2-drm.1%{?ext_man}
%{_mandir}/man1/glmark2-es2-wayland.1%{?ext_man}
%{_mandir}/man1/glmark2-wayland.1%{?ext_man}

%changelog
* Fri Feb 16 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20240215:
  * NativeStateWayland: Explicitly destroy all Wayland resources at shutdown
  * Explicitly release GL related resources at shutdown
  * src/meson.build: add x11 dependency to glx
  * Fix memory leaks using smart pointers
  * Add missing includes in scene-collection.h
* Tue Nov 14 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20231101:
  * GLVisualConfig: By default don't care about the stencil config component
  * Options,GLStateEGL,GLStateGLX: Add option to require a good visual config
  * GLStateEGL,GLStateGLX: Change failure to get a "good" visual config to warning
  * libmatrix: Add Log::warning() function
  * meson.build: fix build and avoid sigsegv
  * NativeStateX11: Add winsys option for position
  * Build,Doc: Update files for 2023.01 release
  * NativeStateMir: Remove Mir/mirclient support
* Thu Jan 19 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230104:
  * ResultsFile: Support storing results in an XML file
  * ResultsFile: Support storing results in a CSV file
  * Options,ResultsFile: Add option to set the results file
  * Introduce infrastructure to support saving results to a file
  * CanvasGeneric: Store individual info elements in separate strings
  * MainLoop: Store indivitual result values in separate strings
  * Scene: Remove trailing ':' from scene info string
  * SceneTerrain: Silence unused variable warning
  * NativeStateGBM: Lock and release the front buffer on flip
  * MainLoop,Scene: Support reporting shader compilation time
  * MainLoop,Scene: Add busy percentage in CPU time results
  * MainLoop,Scene: Support reporting CPU time results
  * Options: Introduce option to specify benchmark results to show
  * Scene: Update elapsed times when a benchmark finishes
  * Scene: Introduce struct to keep track of elapsed time
  * Scene: Introduce infrastructure for more complex scene stats
  * Scene: Move common preparation logic to Scene::prepare
  * Scene: Introduce non-virtual methods to prepare and finish a scene for benchmark
  * GLVisualConfig: Support specifying the config id in --visual-config
  * libmatrix: Support prefix dependent input conversions from string
  * GLStateEGL,GLStateGLX: Fail if no suitable config is found
  * GLStateEGL,GLStateGLX: Don't limit the configs passed to our selection mechanism
  * GLVisualConfig: Penalize configs with components smaller than requested
* Thu Nov 24 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20221116:
  * github: Build x11-gl-egl flavor in CI
  * build: Add x11-gl-egl flavor
  * GLStateGLX: Support multisampled configs
  * GLStateEGL: Support multisampled configs
  * GLVisualConfig: Add multisampling support
  * Add missing newline at end of log messages
  * NativeStateDRM,NativeStateGBM: Support configuring the DRM device
  * Options: Support passing window system specific options
  * NativeStateGBM: Add GBM offscreen backend
* Thu Aug 11 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220712:
  * SceneJellyfish: Fix memory leak
  * SceneRefract: Fix texture leak
  * SceneIdeas: Fix texture leak
  * waflib: fix compatibility with python-3.11
  * NativeStateDRM: Honor visual configuration
* Mon May 16 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220513:
  * GLStateEGL,GLStateGLX: Use SwapInterval 1 for FIFO swap mode
  * NativeStateDrm: Implement swap interval 0
* Thu Apr 28 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220214:
  * github: Run apt-get update to get latest packages
  * CanvasGeneric,CanvasAndroid: Display surface config info
  * Options: Support --version command line argument
  * libmatrix: Add missing <utility> include
  * libmatrix: avoid -Wimplicit-fallthrough
* Tue Jan 18 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211223:
  * Build,Doc: Update files for 2021.12 release
  * NativeStateDrm: Fix crash when we can't become DRM master
* Tue Oct 19 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211008:
  * android: Fix benchmark parameter edition
  * Use highp precision modifier only on GLES
* Tue Sep 14 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210830:
  * GLStateEGL: Support EGL versions < 1.4
  * Fix model loading on big endian.
  * Fix -Wunreachable-code-aggressive.
* Fri May 28 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210521:
  * glad: Update for GL 2.1 + GL_EXT_framebuffer_object
  * Gracefully handle missing GL features
  * NativeStateWayland: Improve surface configuration handling
* Thu Apr 29 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210224:
  * SceneRefract: Fix incorrect generation of mipmap
  * NativeStateWayland: Don't assume order of globals
  * GLStateEGL: Avoid creating two EGLDisplay instances
  * Build,Doc: Update files for 2021.02 release
  * Build: Remove invalid build flavors for meson
  * NativeStateWayland: Support quitting with ESC or Q key
  * NativeStateWayland: Add basic pointer support
  * CanvasGeneric: avoid undefined behavior constructing a std::string with NULL
  * libmatrix: declare Shader::Shader(Shader&&) as noexcept
  * libmatrix: add move constructor to class Shader for v.push_back opt
  * build: glmark2 does not really require libpng version 16
  * SceneBump: Fix precision bug in height rendering
  * SceneDesktop: Draw to correct FBO in off-screen mode
  * SceneShadow: Draw to correct FBO in off-screen mode
  * SceneRefract: Draw to correct FBO in off-screen mode
  * SceneTerrain: Draw to correct FBO in off-screen mode
  * CanvasGeneric: End the frame with glFinish when validating
  * Build: Use the build system wayland-scanner on meson
  * Build: Fix drm-only and wayland-only builds on meson
  * loop,function,conditionals: Fix mediump overflow
  * terrain: Fix precision handling in noise shader
  * terrain: Fix precision bug in light rendering
  * Doc: Document that the -b flag can pass common opts
  * Doc: Update files for meson build system
  * ci: Add build github workflow
  * Build: Meson build system support
  * Build: Use python3 in waf
  * NativeStateWayland: Fix no response to wayland server ping event.
  * Check for proper initialization of native_window and MVC matrix
  * egl: Ensure eglReleaseThread is valid before calling it
  * drm: Don't prefer RGBA component widths larger than 8
* Wed May 27 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200503:
  * Build: Fix Python 3 incompatibility
  * Build,Doc: Update files for 2020.04 release
  * doc: Update --data-path documentation entry
  * Build: Improve configure error message when no flavors are selected
  * Android: Add fastlane metadata for F-Droid release
  * Android: Add unofficial adaptive icon for the android 8+ release
  * Android: Add unofficial icon for the android release
  * Android: Remove old drawables with non standard names
  * Android: Add different resolution of drawable and use sdk name for it
  * Fix UTF-8 in copyright headers
  * Allow version string suffix
  * Port Wayland to xdg-shell window management
  * Allow flavours to generate their own source files
  * Add support for Wayland display-scale events
  * glad: Update to latest upstream version
  * glad: Add README
- Use obscpio
- Change versioning scheme to one consistent with upstream
- Simplify build conditionals
- Use python3 for building
* Thu Dec 19 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.0+git.20190904:
  * Fix Android build
  * Set swap interval to 0 for WGL when possible.
  * Fix win32-gl build.
  * GLState*: Reverse arguments in GLAD loader functions
  * glad: Update glad and add WGL_EXT_swap_control
  * GLStateWGL: Update gotNativeConfig argument type
  * Shadow: change depth sampling to first component
* Wed Jul 24 2019 guillaume.gardet@opensuse.org
- Update to version 0.0+git.20190708:
  * Android: Update documentation
  * Android: Add build script for Linux
  * Android: Add GLAD support to canvas-android
  * Android: Add GLAD libraries to ndk-build
  * Android: Update libjpeg-turbo build
  * Android: Fixes to work with more recent toolchains
  * Build: Fix sqrt check with clang/libc++
  * Add --data-path command line option
  * GLState: change native config type to intptr_t
  * SceneDesktop: don't modify framebuffer zero
  * MainLoop: Move before_scene_setup call before canvas reset
  * Change depth texture sampling to first component
  * waflib: Fixes for python3.7
  * Build: Improve handling of all-{linux,win32} flavors
  * drm: check for resources presence on udev-selected drm devices
  * Fix Windows 32-bit build.
  * Build: Fix for properly building glad-egl targets
  * Add Win32 EGL flavor.
  * Add support for Windows OpenGL via WGL.
  * Add copy of zlib to src/.
  * Update libjpeg-turbo.
  * Build: Use a separate glad-egl build for each EGL platform
  * Add gl, egl and glx loader using GLAD.
* Mon Feb 11 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.0+git.20190205:
  * Use <io.h> for 'isatty' on Windows.
  * Use <algorithm> for std::min/max.
  * Use ios::binary when opening model files.
  * Fix typo on "length"
  * drm: add rockchip to module list
  * gl-state-egl: Fix build on dispmanx-gles2
  * SceneIdeas: Fix (harmless?) typo
  * drm: fix invalid index when finding a suitable encoder
  * drm: set a default encoder for not connected connector
  * drm: add "stm" to list of drm modules
  * drm: prevent crash when CRTC has not been initialized
  * drm: fix newline in error message
  * drm: add "msm" to list of drm modules
  * drm: Add sun4i-drm driver in the list of DRM Modules
- Temporarily switch back to python2 for building to workaround
  Factory build failure
* Thu Jun 14 2018 mpluskal@suse.com
- Update to version 0.0+git.20180608:
  * Add meson driver in list of DRM modules
  * gl-state-egl: Cast native display to void* for eglGetPlatformDisplayEXT
  * gl-state-egl: Release EGL resources on termination
* Thu Mar  8 2018 mpluskal@suse.com
- Update to version 0.0+git.20180208:
  * Allow to limit to a number of frames
  * Build: Exclude dispmanx-glesv2 when building 'all' flavors
  * Port glmark2 to Raspberry Pi's dispmanx.
  * Include a PFNEGLGETPLATFORMDISPLAYEXTPROC typedef for older eglext.h.
  * Mesh: Improve performance of Mesh::update_single_array
  * textures: Fix libpng 1.6 invalid color profile warning
  * NativeStateDRM: fix running without current mode
  * libmatrix: Remove deprecated dynamic exception specifications
  * ShaderSource: Fix clang warning autological-unsigned-zero-compare
* Fri Oct  6 2017 mpluskal@suse.com
- Update to version 0.0+git.20170908:
  * Build,Doc: Update files for 2017.07 release
  * NativeStateDRM: Be explicit about the drmEventContext version we use
  * Fix clang warnings
  * SceneTerrain: Fix off-by-one error in array size
* Fri Jul 28 2017 mpluskal@suse.com
- Update to version 0.0+git.20170713:
  * NativeStateDRM: add imx-drm driver support
  * drm: Add the pl111 and vc4 drm drivers
  * drm: Initialize the page flip handler to 0.
  * SceneTerrain: Add missing header file for std::abs
  * wayland: Fix destruction order of surface-related objects
  * wayland: Don't store the opaque region unnecessarily
  * GLStateEGL: Use eglGetPlatformDisplayEXT when possible
  * NativeStateDRM: Probe the DRM node path to use with udev
* Tue Feb 14 2017 mpluskal@suse.com
- Update to version 0.0+git.20170210:
  * Use monotonic clock
* Sun Jan 22 2017 mpluskal@suse.com
- Packaging changes:
  * Fix building on SLES and Leap
  * Enable parallel build
* Sun Nov 13 2016 mpluskal@suse.com
- Update to version 0.0+git.20160914:
  * Build: Update to waf 1.9.3 and unpack as required by debian policy
  * Build: Remove -Werror from the default build flags
  * Fix C++11 build error
  * Build: Build in c++14 mode
  * wscript: check C libraries using the C compiler
  * Do not use deprecated std::auto_ptr
  * NativeStateWayland: Fix segfault during teardown when failing to connect to wayland compositor
  * NativeStateMir: Fix compilation with c++11/14
  * Build: Don't rebuild common sources needlessly
  * data: Remove unused uniforms from shaders
- Drop upstreamed glmark2-drop-sqrt-check.patch
- Switch versioning to more reasonable one
* Tue Jul 26 2016 mpluskal@suse.com
- Update to version 2014.03+git.20150611:
  * Build: Correct dependencies on matrix-glesv2 target
  * NativeStateX11: Don't terminate --fullscreen if EWMH Atom not found
  * libpng: Allow compilation in C++11 mode
  * Build,Doc: Update files for 2014.03 release
  * Build: Support libpng 1.6
  * NativeStateMir: Update for newest Mir client API
  * Fix clang build errors
  * Build: Exclude git repository files from dist tarball
  * Build: Allow user defined CXXFLAGS to override all built-in flags
  * Build: Allow disabling the -Werror compiler flag
- Add _service
- Some spec file cleanups
* Sun Jul 17 2016 malcolmlewis@opensuse.org
- Add glmark2-drop-sqrt-check.patch: Add upstream patch to drop
  sqrt check. See https://github.com/glmark2/glmark2/issues/15.
- Add CXXFLAGS no-deprecated-declarations and no-werror option to
  build. See https://github.com/glmark2/glmark2/issues/20.
* Fri Oct  9 2015 malcolmlewis@opensuse.org
- Clean up runtime warning - libpng warning: iCCP: known incorrect
  sRGB profile.
* Thu Oct  8 2015 malcolmlewis@opensuse.org
- Initial build.
